%bcond_with reconf

Name: libarchive
Version: 3.3.3
Release: 2
License: BSD-2-Clause
Summary: Multi-format archive and compression library
Url: https://www.libarchive.org

Source0: https://www.libarchive.org/downloads/libarchive-%{version}.tar.gz

Patch0: libarchive-CVE-2019-18408.patch

%if %{with reconf}
BuildRequires: autoconf
BuildRequires: automake
BuildRequires: libtool
%endif

BuildRequires: openssl-devel > 1.1
BuildRequires: zlib-devel
BuildRequires: libxml2-devel

%description
Multi-format archive and compression library

The source distribution includes the libarchive library, the bsdtar and bsdcpio
command-line programs, full test suite, and documentation.


%package -n libarchive13
Summary: libarchive library
Provides: %{name} = %{version}

%description -n libarchive13
 The libarchive library features:

- Support for a variety of archive and compression formats.
- Robust automatic format detection, including archive/compression combinations such as tar.gz.
- Zero-copy internal architecture for high performance.
- Streaming architecture eliminates all limits on size of archive, limits on entry sizes depend on particular formats.
- Carefully factored code to minimize bloat when programs are statically linked.
- Growing test suite to verify correctness of new ports.
- Works on most POSIX-like systems (including FreeBSD, Linux, Solaris, etc.)
- Supports Windows, including Cygwin, MinGW, and Visual Studio.

%package tools
Summary: libarchive utilities
Requires: %{name} = %{version}-%{release}

%description tools
The bsdtar and bsdcpio command-line utilities are feature- and
performance-competitive with other tar and cpio implementations.


%package devel
Summary: libarchive development files
Requires: %{name} = %{version}-%{release}

%description devel
libarchive development files


%prep
%setup -q

%patch0 -p1

%build

%if %{with reconf}
autoreconf -fi
%else
%define _host powerpc64-ibm-aix6
%endif

%configure \
  ac_cv_func_faccessat=no \
  ac_cv_func_fchmodat=no \
  ac_cv_func_fchownat=no \
  ac_cv_func_fstatat=no \
  ac_cv_func_futimesat=no \
  ac_cv_func_linkat=no \
  ac_cv_func_lstat=yes \
  ac_cv_func_mkdirat=no \
  ac_cv_func_mkfifoat=no \
  ac_cv_func_mknodat=no \
  ac_cv_func_openat=no \
  ac_cv_func_readlinkat=no \
  ac_cv_func_renameat=no \
  ac_cv_func_symlinkat=no \
  ac_cv_func_unlinkat=no \
  ac_cv_func_utimensat=no \
  CPPFLAGS='-I%{_includedir}' \
  LDFLAGS="-Wl,-brtl -Wl,-blibpath:%{_libdir}:/QOpenSys/usr/lib -L%{_libdir}" \
  LIBS="-lpthread" \
  --with-aix-soname=svr4 \
  --enable-posix-regex-lib=libpcreposix \
  --without-lz4 \
  --without-lzo2 \
  --without-nettle \
  --disable-xattr \
  --disable-acl \
  --disable-static \
  --disable-rpath \
  # end

%make_build


%install

%make_install

rm %{buildroot}%{_mandir}/man5/cpio.5
rm %{buildroot}%{_mandir}/man5/tar.5

%files -n libarchive13
%defattr(-, qsys, *none)

%{_libdir}/libarchive.so.13

%files tools
%defattr(-, qsys, *none)

%{_bindir}/bsdtar
%{_bindir}/bsdcat
%{_bindir}/bsdcpio

%{_mandir}/man1/bsdcat.1*
%{_mandir}/man1/bsdcpio.1*
%{_mandir}/man1/bsdtar.1*

%{_mandir}/man5/libarchive-formats.5*
%{_mandir}/man5/mtree.5*

%files devel
%defattr(-, qsys, *none)

%{_includedir}/*
%{_libdir}/*.so

%{_mandir}/man3/archive_entry.3*
%{_mandir}/man3/archive_entry_acl.3*
%{_mandir}/man3/archive_entry_linkify.3*
%{_mandir}/man3/archive_entry_paths.3*
%{_mandir}/man3/archive_entry_perms.3*
%{_mandir}/man3/archive_entry_stat.3*
%{_mandir}/man3/archive_entry_time.3*
%{_mandir}/man3/archive_read.3*
%{_mandir}/man3/archive_read_add_passphrase.3*
%{_mandir}/man3/archive_read_data.3*
%{_mandir}/man3/archive_read_disk.3*
%{_mandir}/man3/archive_read_extract.3*
%{_mandir}/man3/archive_read_filter.3*
%{_mandir}/man3/archive_read_format.3*
%{_mandir}/man3/archive_read_free.3*
%{_mandir}/man3/archive_read_header.3*
%{_mandir}/man3/archive_read_new.3*
%{_mandir}/man3/archive_read_open.3*
%{_mandir}/man3/archive_read_set_options.3*
%{_mandir}/man3/archive_util.3*
%{_mandir}/man3/archive_write.3*
%{_mandir}/man3/archive_write_blocksize.3*
%{_mandir}/man3/archive_write_data.3*
%{_mandir}/man3/archive_write_disk.3*
%{_mandir}/man3/archive_write_filter.3*
%{_mandir}/man3/archive_write_finish_entry.3*
%{_mandir}/man3/archive_write_format.3*
%{_mandir}/man3/archive_write_free.3*
%{_mandir}/man3/archive_write_header.3*
%{_mandir}/man3/archive_write_new.3*
%{_mandir}/man3/archive_write_open.3*
%{_mandir}/man3/archive_write_set_options.3*
%{_mandir}/man3/archive_write_set_passphrase.3*
%{_mandir}/man3/libarchive.3*
%{_mandir}/man3/libarchive_changes.3*
%{_mandir}/man3/libarchive_internals.3*

%{_libdir}/pkgconfig/libarchive.pc


%changelog
* Thu Nov 4 2021 Jason Hansen <stymie@us.ibm.com> - 3.3.3
- Intra-package Requires need version and release

* Wed Nov 18 2020 Abdirahim Musse <abdirahim.musse@ibm.com> - 3.3.3
- Use brp-rm-libtool-files

* Wed May 27 2020 Kevin Adler <kadler@us.ibm.com> - 3.3.3
- Use generic paths for man and info pages to allow for compression

* Fri Feb 28 2020 Jesse Gorzinski <jgorzins@us.ibm.com> - 3.3.3
- Upgrade to version 3.3.3

* Tue Jan 28 2020 Kevin Adler <kadler@us.ibm.com> - 3.3.1
- Add patch for CVE-2019-18408

* Thu Dec 12 2019 Kevin Adler <kadler@us.ibm.com> - 8.1p1
- Link against OpenSSL 1.1

* Thu Nov 21 2019 Kevin Adler <kadler@us.ibm.com> - 3.3.1
- Disable half-implemented *at APIs, fixing IBM i 7.2 build

* Tue Nov 19 2019 Kevin Adler <kadler@us.ibm.com> - 3.3.1
- Use SPDX license identifier

* Sat Mar 03 2018 - Kevin Adler <kadler@us.ibm.com>
- Major spec cleanups

* Wed Dec 20 2017 - Kevin Adler <kadler@us.ibm.com>
- Remove 64-bit GCC script workarounds

* Wed Nov 22 2017 - Kevin Adler <kadler@us.ibm.com>
- Add BuildRequires

* Tue Nov 21 2017 - Kevin Adler <kadler@us.ibm.com>
- remove unneeded Provides
- remove tar and cpio manuals since they conflict with GNU coreutils

* Tue Nov 21 2017 - Kevin Adler <kadler@us.ibm.com>
- Remove outdated TODO comments

* Tue Nov 07 2017 - Kevin Adler <kadler@us.ibm.com>
- Fix license

* Thu Aug 24 2017 - Kevin Adler <kadler@us.ibm.com>
- Fixes for ppc64 libarchive

* Thu Aug 24 2017 - Kevin Adler <kadler@us.ibm.com>
- Add missing defattr(-, qsys, *none)
